import Layout from "./components/Layout/Layout";
import { Routes, Route } from "react-router-dom";
import ProductFormPage from "./containers/ProductFormPage/ProductFormPage";
import ProductsPage from "./containers/ProductsPage/ProductsPage";
import Login from "./containers/Login/Login";
import Register from "./containers/Register/Register";
import PrivateRoute from "./utils/PrivateRoute";
import UserForm from "./components/UserForm/UserForm";
import ForgotPasswordForm from "./components/ForgotPasswordForm/ForgotPasswordForm";
import ResetPasswordForm from "./components/ResetPasswordForm/ResetPasswordForm";
import PermissionRoute from "./utils/PermissionRoute";
import { ERoles } from "./enums/ERoles";

const App = () => {
  return (
    <Routes>
      <Route element={<PrivateRoute />}>
        <Route element={<Layout />} >
          <Route path={"/"} element={<h1>HOME</h1>} />
          <Route path={"/products"} element={<ProductsPage />} />
          <Route element={<PermissionRoute roles={[ERoles.SUPER_ADMIN]} />}>
              <Route path={"/add-product"} element={<ProductFormPage />} />
          </Route>
          <Route element={<PermissionRoute roles={[ERoles.ADMIN]} />}>
              <Route path={"/edit-user"} element={<UserForm />} />
          </Route>
        </Route>  
      </Route>
      <Route path={"/login"} element={<Login />} />
      <Route path={"/register"} element={<Register />} />
      <Route path={"/forgot-password"} element={<ForgotPasswordForm />} />
      <Route path={"/reset-password"} element={<ResetPasswordForm />} />
    </Routes>
  );
};

export default App;
