import React, {FormEvent, useState, ChangeEvent} from 'react'
import { useDispatch } from 'react-redux'
import { useSearchParams } from 'react-router-dom'
import { AppDispatch } from '../../store/store'
import { resetPassword } from '../../store/users/users.slice'
import styles from './ResetPasswordForm.module.css'


const ResetPasswordForm: React.FunctionComponent = (): React.ReactElement => {
    const dispatch: AppDispatch = useDispatch()
    const [searchParams, setSearchParams] = useSearchParams();
    const [errorMessage, setErrorMessage] = useState<string>('')
    const [userValues, setUserValues] = useState<{token: string, password: string, password_repeat: string}>({
        token: searchParams.get('token') || '',
        password: '',
        password_repeat: ''
    })
    const inputHandler = (e: ChangeEvent<HTMLInputElement>): void => {
        setUserValues(prevState => {
            return {...prevState, [e.target.name]: e.target.value}
        })
    }
    const submitHandler = (e: FormEvent) => {
        e.preventDefault()
        if (userValues.password !== userValues.password_repeat) {
            setErrorMessage('Passwords are different')
            return
        }
        dispatch(resetPassword({password: userValues.password, token: userValues.token}))
    }
    return (
        <div className={styles.ResetPasswordForm__frame}>
            <form className={styles.ResetPasswordForm} onSubmit={submitHandler}>
                <h6>{errorMessage}</h6>
                <input 
                    name={'password'} 
                    type="text" 
                    placeholder="Password" 
                    value={userValues.password}
                    onChange={inputHandler}
                    className={styles.ResetPasswordForm__input}
                />
                <input 
                    name={'password_repeat'} 
                    type="text" 
                    placeholder="Repeat password" 
                    value={userValues.password_repeat}
                    onChange={inputHandler}
                    className={styles.ResetPasswordForm__input}
                />
                <button className={styles.ResetPasswordForm__button}>SEND</button>
            </form>
        </div>
    )
}

export default ResetPasswordForm