import React, { ChangeEvent, FormEvent, FunctionComponent, ReactElement, useState } from "react";
import { shallowEqual, useDispatch, useSelector } from "react-redux";
import IProductDto from "../../interfaces/IProductDto";
import IUserCreateDto from "../../interfaces/IUserCreateDto";
import { createProduct } from "../../store/products/products.slice";
import { AppDispatch, AppState } from "../../store/store";
import { editUser } from "../../store/users/users.slice";
import styles from './UserForm.module.css'

const UserForm: FunctionComponent = (): ReactElement => {
    const dispatch: AppDispatch = useDispatch()
    const [isChangingPassword, setIsChangingPassword] = useState<boolean>(false)
    const [errorMessage, setErrorMessage] = useState<string>('')
    const {user} = useSelector((state: AppState) => state.users, shallowEqual)
    const [userValues, setUserValues] = useState<IUserCreateDto & {password_repeat: string}>({
        username: user?.username || '',
        password: '',
        password_repeat: ''
    })
    const inputHandler = (e: ChangeEvent<HTMLInputElement>): void => {
        setUserValues(prevState => {
            return {...prevState, [e.target.name]: e.target.value}
        })
    }
    const submitHandler = (e: FormEvent) => {
        e.preventDefault()
        console.log('isChangingPassword', isChangingPassword)
        if (isChangingPassword && userValues.password !== userValues.password_repeat) {
            setErrorMessage('Passwords are different')
            return
        }
        if (userValues.username.trim() === '') {
            setErrorMessage('Username cannot be empty')
            return
        }
        dispatch(editUser({
            username: userValues.username,
            password: isChangingPassword ? userValues.password : ''
        }))
    }

    const toggleChangePassword = () => {
        setIsChangingPassword(!isChangingPassword)
    }
    return (
        <div className={styles.UserForm__frame}>
            <form className={styles.UserForm} onSubmit={submitHandler}>
                <h6>{errorMessage}</h6>
                <input 
                    name={'username'} 
                    type="text" 
                    placeholder="Username" 
                    value={userValues.username}
                    onChange={inputHandler}
                    className={styles.UserForm__input}
                />
                <label>
                    <input type="checkbox" 
                        onChange={toggleChangePassword} 
                        checked={isChangingPassword} />
                    Change password?
                </label>
                <input 
                    name={'password'} 
                    type="text" 
                    disabled={!isChangingPassword}
                    placeholder="Password" 
                    value={userValues.password}
                    onChange={inputHandler}
                    className={styles.UserForm__input}
                />
                <input 
                    name={'password_repeat'} 
                    type="text" 
                    disabled={!isChangingPassword}
                    placeholder="Repeat password" 
                    value={userValues.password_repeat}
                    onChange={inputHandler}
                    className={styles.UserForm__input}
                />
                <button className={styles.UserForm__button}>SEND</button>
            </form>
        </div>
    )
}

export default UserForm